@@ -15,6 +15,7 @@
 
 import argparse
 import cStringIO
+import logging
 import os
 import re
 import sys
@@ -24,7 +25,7 @@ import mox
 import testtools
 from testtools import matchers
 
-from neutronclient.common import exceptions
+from neutronclient.common import clientmanager
 from neutronclient import shell as openstack_shell
 
 
@@ -37,11 +38,6 @@ DEFAULT_TOKEN = '3bcc3d3a03f44e3d8377f9247b0ad155'
 DEFAULT_URL = 'http://quantum.example.org:9696/'
 
 
-class NoExitArgumentParser(argparse.ArgumentParser):
-    def error(self, message):
-        raise exceptions.CommandError(message)
-
-
 class ShellTest(testtools.TestCase):
 
     FAKE_ENV = {
@@ -51,10 +47,6 @@ class ShellTest(testtools.TestCase):
         'OS_TENANT_NAME': DEFAULT_TENANT_NAME,
         'OS_AUTH_URL': DEFAULT_AUTH_URL}
 
-    def _tolerant_shell(self, cmd):
-        t_shell = openstack_shell.NeutronShell('2.0')
-        t_shell.run(cmd.split())
-
     # Patch os.environ to avoid required auth info.
     def setUp(self):
         super(ShellTest, self).setUp()
@@ -64,65 +56,89 @@ class ShellTest(testtools.TestCase):
                 fixtures.EnvironmentVariable(
                     var, self.FAKE_ENV[var]))
 
-        # Make a fake shell object, a helping wrapper to call it, and a quick
-        # way of asserting that certain API calls were made.
-        global shell, _shell, assert_called, assert_called_anytime
-        _shell = openstack_shell.NeutronShell('2.0')
-        shell = lambda cmd: _shell.run(cmd.split())
-
-    def shell(self, argstr):
-        orig = sys.stdout
+    def shell(self, argstr, check=False):
+        orig = (sys.stdout, sys.stderr)
         clean_env = {}
         _old_env, os.environ = os.environ, clean_env.copy()
         try:
             sys.stdout = cStringIO.StringIO()
+            sys.stderr = cStringIO.StringIO()
             _shell = openstack_shell.NeutronShell('2.0')
             _shell.run(argstr.split())
         except SystemExit:
             exc_type, exc_value, exc_traceback = sys.exc_info()
             self.assertEqual(exc_value.code, 0)
         finally:
-            out = sys.stdout.getvalue()
+            stdout = sys.stdout.getvalue()
+            stderr = sys.stderr.getvalue()
             sys.stdout.close()
-            sys.stdout = orig
+            sys.stderr.close()
+            sys.stdout, sys.stderr = orig
             os.environ = _old_env
-        return out
+        return stdout, stderr
 
     def test_run_unknown_command(self):
-        openstack_shell.NeutronShell('2.0').run('fake')
+        self.useFixture(fixtures.FakeLogger(level=logging.DEBUG))
+        stdout, stderr = self.shell('fake', check=True)
+        self.assertFalse(stdout)
+        self.assertEqual("Unknown command ['fake']", stderr.strip())
 
     def test_help(self):
         required = 'usage:'
-        help_text = self.shell('help')
+        help_text, stderr = self.shell('help')
         self.assertThat(
             help_text,
             matchers.MatchesRegex(required))
+        self.assertFalse(stderr)
 
     def test_help_on_subcommand(self):
         required = [
             '.*?^usage: .* quota-list']
-        stdout = self.shell('help quota-list')
+        stdout, stderr = self.shell('help quota-list')
         for r in required:
             self.assertThat(
                 stdout,
                 matchers.MatchesRegex(r, re.DOTALL | re.MULTILINE))
+        self.assertFalse(stderr)
 
     def test_help_command(self):
         required = 'usage:'
-        help_text = self.shell('help network-create')
+        help_text, stderr = self.shell('help network-create')
         self.assertThat(
             help_text,
             matchers.MatchesRegex(required))
+        self.assertFalse(stderr)
 
     def test_unknown_auth_strategy(self):
-        self.shell('--os-auth-strategy fake quota-list')
+        self.useFixture(fixtures.FakeLogger(level=logging.DEBUG))
+        stdout, stderr = self.shell('--os-auth-strategy fake quota-list')
+        self.assertFalse(stdout)
+        self.assertEqual('You must provide a service URL via '
+                         'either --os-url or env[OS_URL]', stderr.strip())
 
     def test_auth(self):
-        self.shell(' --os-username test'
-                   ' --os-password test'
-                   ' --os-tenant-name test'
-                   ' --os-auth-url http://127.0.0.1:5000/'
-                   ' --os-auth-strategy keystone quota-list')
+        #import pdb; pdb.set_trace()
+        neutron_shell = openstack_shell.NeutronShell('2.0')
+        self.addCleanup(self.mox.UnsetStubs)
+        self.mox.StubOutWithMock(clientmanager.ClientManager, '__init__')
+        self.mox.StubOutWithMock(neutron_shell, 'run_subcommand')
+        clientmanager.ClientManager.__init__(
+            token='', url='', auth_url='http://127.0.0.1:5000/',
+            tenant_name='test', tenant_id='tenant_id',
+            username='test', user_id='',
+            password='test', region_name='', api_version={'network': '2.0'},
+            auth_strategy='keystone', service_type='network',
+            endpoint_type='publicURL', insecure=False, ca_cert=None,
+            log_credentials=True)
+        neutron_shell.run_subcommand(['quota-list'])
+        self.mox.ReplayAll()
+        cmdline = ('--os-username test '
+                   '--os-password test '
+                   '--os-tenant-name test '
+                   '--os-auth-url http://127.0.0.1:5000/ '
+                   '--os-auth-strategy keystone quota-list')
+        neutron_shell.run(cmdline.split())
+        self.mox.VerifyAll()
 
     def test_build_option_parser(self):
         neutron_shell = openstack_shell.NeutronShell('2.0')
@@ -132,7 +148,6 @@ class ShellTest(testtools.TestCase):
     def test_main_with_unicode(self):
         self.mox.StubOutClassWithMocks(openstack_shell, 'NeutronShell')
         qshell_mock = openstack_shell.NeutronShell('2.0')
-        #self.mox.StubOutWithMock(qshell_mock, 'run')
         unicode_text = u'\u7f51\u7edc'
         argv = ['net-list', unicode_text, unicode_text.encode('utf-8')]
         qshell_mock.run([u'net-list', unicode_text,
